@@ -1,11 +1,13 @@
 mod command;
 mod enter;
 mod exit;
+mod goto;
 mod next;
 mod prev;
 
 pub use command::Shells;
 pub use enter::Enter;
 pub use exit::Exit;
+pub use goto::Goto;
 pub use next::Next;
 pub use prev::Previous;
